@@ -4,7 +4,8 @@ import textwrap
 
 from ts_cli.config.cli_config import VALID_KEYS, CliConfig, write_config_file
 from ts_cli.config.util import load_from_yaml_or_json_if_present
-from ts_cli.util.emit import emit_critical, emit_warning
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_warning
 
 
 def add_config_parser(subparsers):
@@ -51,7 +52,7 @@ def add_config_get_parser(subparsers):
         description=textwrap.dedent(
             """
             Retrieves the currently set configuration option
-            
+
             If there is no option set for the specified profile,
             the get command will reach out into the global scope
             to look for a configuration option.
@@ -75,7 +76,7 @@ def add_config_unset_parser(subparsers):
         description=textwrap.dedent(
             """
             Removes the currently set configuration option
-            
+
             If there is no option set for the specified profile,
             the unset command will *not* unset the global scope,
             and will instead exit unsuccessfully with a warning
@@ -95,16 +96,16 @@ def add_config_set_parser(subparsers):
         description=textwrap.dedent(
             """
             Saves a new configuration option at the specified key
-            
+
                 ts-cli config set profile development
-            
+
             Use the --global flag to make the option apply to all
             profiles by default
-            
+
             Use the the `--false` or `--true` flags in place of
             the `value` positional argument to pass a boolean
             instead of a string. For example:
-            
+
               ts-cli config set ignore-ssl --true
             """
         ),
@@ -169,7 +170,9 @@ def config_get(args):
 def config_set(args):
     cli_config = CliConfig(args)
     if cli_config.profile is not None and args.key == "profile":
-        emit_critical(f"Cannot set profile config inside profile {cli_config.profile}")
+        raise CriticalError(
+            f"Cannot set profile config inside profile {cli_config.profile}"
+        )
     if not write_config_file(cli_config.profile, {args.key: args.value}):
         sys.exit(1)
 
