@@ -8,8 +8,11 @@ from typing import List, Optional
 
 from jinja2 import Template
 
+from ts_cli.commands.init_cmd.files import delete, get_conflicts
 from ts_cli.commands.init_cmd.init_artifact_config import (
     InitArtifactConfig,
+    InitDataAppConfig,
+    InitTaskScriptReferenceConfig,
     InitTemplateConfig,
 )
 from ts_cli.commands.init_cmd.kinds import KIND_TEMPLATES, KINDS, TEMPLATES
@@ -18,9 +21,9 @@ from ts_cli.config.cli_config import CliConfig
 from ts_cli.config.util import to_version
 from ts_cli.errors.critical_error import CriticalError
 from ts_cli.util.emit import emit_error, emit_warning
-from ts_cli.util.files import copy, delete, get_conflicts
+from ts_cli.util.files import copy
 
-MAX_KNOWN_PLATFORM_VERSION = 4.3
+MAX_KNOWN_PLATFORM_VERSION = 4.4
 
 
 def add_init_parser(subparsers):
@@ -47,11 +50,12 @@ def add_init_parser(subparsers):
 
                 The kind configuration field is required.
 
-                Each template uses up to 3 artifact configurations,
-                    protocol, task-script, or ids
+                Each template uses up to 3 of the following artifact configurations;
+                    protocol, task-script, ids, or data-app
                   consisting of the following fields:
                     namespace, slug, version
-                  Additionally, for the task-script artifact, there is the function field.
+                  Additionally, for the task-script artifact referenced by the protocol
+                    template, there is the function field.
                 While artifact configuration fields are not required, the init command will
                   sequentially check each of the following locations for each configuration:
                     1. The respective command argument for the specific artifact type
@@ -126,6 +130,11 @@ def init_cmd_args(parser: ArgumentParser):
         type=to_version,
         help="Artifact version configuration",
     )
+    artifact_group.add_argument(
+        "--function",
+        type=str,
+        help="Task Script function configuration",
+    )
 
     protocol_group = parser.add_argument_group("Protocol Configuration")
     protocol_group.add_argument(
@@ -156,6 +165,28 @@ def init_cmd_args(parser: ArgumentParser):
         type=to_version,
         help="Task Script version configuration",
     )
+    task_script_group.add_argument(
+        "--task-script-function",
+        type=str,
+        help="Task Script function configuration",
+    )
+
+    data_app_group = parser.add_argument_group("Data App Configuration")
+    data_app_group.add_argument(
+        "--data-app-namespace",
+        type=any_namespace_type,
+        help="Data App namespace configuration",
+    )
+    data_app_group.add_argument(
+        "--data-app-slug",
+        type=str,
+        help="Data App slug configuration",
+    )
+    data_app_group.add_argument(
+        "--data-app-version",
+        type=to_version,
+        help="Data App version configuration",
+    )
 
     ids_group = parser.add_argument_group("IDS Configuration")
     ids_group.add_argument(
@@ -199,20 +230,21 @@ def get_pretty_name(artifact_type: str) -> str:
         return "IDS"
     elif artifact_type == "tetraflow":
         return "Tetraflow"
+    elif artifact_type == "data-app":
+        return "Data App"
+    elif artifact_type == "schema":
+        return "Schema"
     else:
         raise CriticalError(f"Unrecognized type: {artifact_type}")
 
 
-def init_artifact_config(
-    artifact_type: str, args, defaults: dict, *, has_function=False
-):
+def init_artifact_config(artifact_type: str, args, defaults: dict):
     return InitArtifactConfig(
         args,
         interactive=args.interactive,
         type_pretty=get_pretty_name(artifact_type),
         artifact_type=artifact_type,
         defaults=defaults,
-        has_function=has_function,
     )
 
 
@@ -232,8 +264,8 @@ def task_script_template_config(args) -> List[InitArtifactConfig]:
 
 def protocol_template_config(args) -> List[InitArtifactConfig]:
     protocol = init_artifact_config("protocol", args, {})
-    task_script = init_artifact_config(
-        "task-script", args, EXAMPLE_LOCATION, has_function=True
+    task_script = InitTaskScriptReferenceConfig(
+        args, defaults=EXAMPLE_LOCATION, interactive=args.interactive
     )
     return [protocol, task_script]
 
@@ -255,6 +287,16 @@ def tetraflow_template_config(args) -> List[InitArtifactConfig]:
     return [tetraflow]
 
 
+def data_app_template_config(args) -> List[InitArtifactConfig]:
+    data_app = InitDataAppConfig(args, interactive=args.interactive)
+    return [data_app]
+
+
+def schema_template_config(args) -> List[InitArtifactConfig]:
+    schema = init_artifact_config("schema", args, {})
+    return [schema]
+
+
 def create_template_config_list(args, kind: str) -> List[InitArtifactConfig]:
     if kind == "task-script":
         configs = task_script_template_config(args)
@@ -266,6 +308,10 @@ def create_template_config_list(args, kind: str) -> List[InitArtifactConfig]:
         configs = all_template_config(args)
     elif kind == "tetraflow":
         configs = tetraflow_template_config(args)
+    elif kind == "data-app":
+        configs = data_app_template_config(args)
+    elif kind == "schema":
+        configs = schema_template_config(args)
     else:
         raise CriticalError(f"Invalid kind provided: {kind}")
     for config in configs:
@@ -274,11 +320,9 @@ def create_template_config_list(args, kind: str) -> List[InitArtifactConfig]:
 
 
 def create_environment(configs: List[InitArtifactConfig]) -> dict:
-    environment = {}
-    for config in configs:
-        for key in config.keys:
-            environment[f"{config.prefix}_{key}"] = config.get(key)
-    return environment
+    return {
+        f"{config.prefix}_{key}": value for config in configs for key, value in config
+    }
 
 
 def list_template_versions_in_dir(template_path_dir: Path) -> List[float]:
@@ -348,12 +392,18 @@ def pick_template(
 
 
 def resolve_conflicts(
-    *, template_directory, target_directory, overwrite, preserve_templates
+    *,
+    template_directory,
+    target_directory,
+    overwrite,
+    preserve_templates,
+    target_path_transformer=lambda x: x,
 ):
     conflicting_entries = get_conflicts(
         src=template_directory,
         dst=target_directory,
         preserve_templates=preserve_templates,
+        dst_path_transformer=target_path_transformer,
     )
     if conflicting_entries and not overwrite:
         for entry in conflicting_entries:
@@ -385,15 +435,21 @@ def init(args):
         target_directory=args.target,
         overwrite=args.overwrite,
         preserve_templates=args.preserve_templates,
+        target_path_transformer=lambda path: Template(path).render(environment),
     )
 
     with TemporaryDirectory() as temporary_directory:
-        copy(src=template_directory, dst=temporary_directory)
-        for path in Path(temporary_directory).glob("**/*.template"):
-            template = path.read_text()
-            content = Template(template).render(environment)
-            path.with_name(path.stem).write_text(content)
+        copy(
+            src=template_directory,
+            dst=temporary_directory,
+            dst_path_transformer=lambda path: Template(path).render(environment),
+        )
 
+        for path in Path(temporary_directory).glob("**/*.template"):
+            template = path.read_text(encoding="utf-8")
+            content = Template(template).render(environment)
+            path.with_name(path.stem).write_text(content, encoding="utf-8")
             if not args.preserve_templates:
                 path.unlink()
+
         copy(src=temporary_directory, dst=args.target)
