@@ -3,6 +3,8 @@ KIND_TEMPLATES = {
     "protocol": ["default"],
     "task-script": ["default"],
     "tetraflow": ["spark"],
+    "data-app": ["streamlit"],
+    "schema": ["default"],
 }
 
 KINDS = sorted(KIND_TEMPLATES.keys())
