@@ -9,6 +9,7 @@ from time import sleep
 import simplejson as json
 
 from ts_cli.api import TsApi
+from ts_cli.commands.init_cmd.kinds import KINDS
 from ts_cli.commands.utils import existing_folder_type, private_namespace_type
 from ts_cli.config.api_config import ApiConfig
 from ts_cli.config.publish_artifact_config import PublishArtifactConfig
@@ -109,7 +110,7 @@ def publish_cmd_args(parser: argparse.ArgumentParser):
     artifact_config.add_argument(
         "--type",
         type=str,
-        choices=["connector", "ids", "protocol", "task-script", "tetraflow"],
+        choices=KINDS,
         help="artifact type",
     )
     artifact_config.add_argument(
@@ -158,6 +159,12 @@ def publish_cmd_args(parser: argparse.ArgumentParser):
     parser.add_argument(
         "--dry-run", action="store_true", help="skip actual artifact publishing"
     )
+    parser.add_argument(
+        "--verbose",
+        "-v",
+        action="store_true",
+        help="Enable verbose output for debugging",
+    )
 
     api_config = parser.add_argument_group("API Configuration")
     ssl_group = api_config.add_mutually_exclusive_group()
@@ -248,7 +255,7 @@ def monitor_artifact_build(ts_api: TsApi, build_id: str):
     print("", flush=True)
 
     if last_status == "FAILED":
-        raise Exception("Build failed.")
+        raise CriticalError("Build failed.")
 
 
 def publish(args):
@@ -259,7 +266,7 @@ def publish(args):
     """
     artifact_config = PublishArtifactConfig(args, interactive=args.interactive)
     api_config = ApiConfig(args)
-    ts_api = TsApi(api_config)
+    ts_api = TsApi(api_config, verbose=getattr(args, "verbose", False))
 
     with TemporaryDirectory() as temp_directory:
         copy_included_files_to(
