@@ -12,7 +12,11 @@ def update_manifest_fields(manifest: dict, artifact_config: ArtifactConfig):
     :param artifact_config:
     :return:
     """
-    manifest["type"] = artifact_config.type
+    manifest_type = (
+        "connector" if artifact_config.type == "data-app" else artifact_config.type
+    )
+
+    manifest["type"] = manifest_type
     manifest["namespace"] = artifact_config.namespace
     manifest["slug"] = artifact_config.slug
     manifest["version"] = artifact_config.version
@@ -29,7 +33,7 @@ def update_manifest(path: str, artifact_config: ArtifactConfig) -> dict:
     if Path(path, "manifest.json").exists():
         manifest = load_from_json_file_if_present(Path(path, "manifest.json"))
         manifest = update_manifest_fields(manifest, artifact_config)
-        with open(Path(path, "manifest.json"), "w") as file:
+        with open(Path(path, "manifest.json"), "w", encoding="utf-8") as file:
             file.write(json.dumps(manifest))
         return manifest
     return update_manifest_fields({}, artifact_config)
