@@ -3,8 +3,6 @@ from pathlib import Path
 
 from ids_validator.ids_validator import validate_ids_using_tdp_artifact
 from ids_validator.tdp_api import APIConfig as IDSValidatorAPIConfig
-from ts_protocol_virtual_machine import compiler
-from ts_protocol_virtual_machine.messages import Message
 
 from ts_cli.config.api_config import ApiConfig
 from ts_cli.config.util import (
@@ -12,7 +10,7 @@ from ts_cli.config.util import (
     load_from_yaml_file_if_present,
 )
 from ts_cli.errors.critical_error import CriticalError
-from ts_cli.util.emit import emit_error, emit_warning
+from ts_cli.util.emit import emit_error, emit_info, emit_warning
 
 from .validator import Validator
 
@@ -45,6 +43,8 @@ def get_source_validator(
     """
     if validator_type == "connector":
         return ConnectorValidator(path=path, exiting=exiting)
+    if validator_type == "data-app":
+        return DataAppValidator(path=path, exiting=exiting)
     if validator_type == "ids":
         return IdsValidator(path=path, exiting=exiting, api_config=api_config)
     if validator_type == "task-script":
@@ -53,6 +53,8 @@ def get_source_validator(
         return ProtocolValidator(path=path, exiting=exiting)
     if validator_type == "tetraflow":
         return TetraflowValidator(path=path, exiting=exiting)
+    if validator_type == "schema":
+        return SchemaValidator(path=path, exiting=exiting)
     raise CriticalError(f"Invalid type provided: {validator_type}")
 
 
@@ -79,6 +81,39 @@ class ConnectorValidator(SourceValidator):
             )
 
 
+class DataAppValidator(SourceValidator):
+    """
+    Validates a Data App artifact's source files
+    """
+
+    def validate(self):
+        # Check for image.tar (same as connector)
+        package_content = os.listdir(self._path)
+        if "image.tar" not in package_content:
+            raise CriticalError(
+                "Data app package must contain 'image.tar'. "
+                "Build your data app first with: poetry run poe build-for-publish"
+            )
+
+        # Check manifest has correct subtype label
+        manifest_path = Path(self._path, "manifest.json")
+        if manifest_path.exists():
+            manifest = load_from_json_file_if_present(manifest_path)
+            labels = manifest.get("labels", [])
+            labels = labels if isinstance(labels, list) else []
+            subtype_labels = [
+                label
+                for label in labels
+                if (isinstance(label, dict) and label.get("name") == "subtype")
+            ]
+
+            if not subtype_labels or subtype_labels[0].get("value") != "data-app":
+                raise CriticalError(
+                    "Data app manifest must include label: "
+                    '{"name": "subtype", "value": "data-app"}'
+                )
+
+
 class IdsValidator(SourceValidator):
     """
     Validates an IDS artifact's source files
@@ -129,12 +164,6 @@ class ProtocolValidator(SourceValidator):
     Validates a Protocol artifact's source files
     """
 
-    @staticmethod
-    def format_message(filename: str, message: Message):
-        path = f"[{message.source_path}] " if message.source_path else ""
-        expression = f"$( {message.expression} ) " if message.expression else ""
-        return f"{filename} >> {path}{expression}{message.content}"
-
     @staticmethod
     def load_protocol(path: Path):
         if path.suffix == ".json":
@@ -143,14 +172,28 @@ class ProtocolValidator(SourceValidator):
 
     @staticmethod
     def validate_v3_protocol(filename: str, protocol: dict):
+        try:
+            from ts_protocol_virtual_machine import compiler
+            from ts_protocol_virtual_machine.messages import Message
+        except ImportError:
+            emit_info(
+                "Skipping protocol v3 validation because the 'protocol-validation' extra is not installed"
+            )
+            return
+
+        def format_message(message: Message):
+            path = f"[{message.source_path}] " if message.source_path else ""
+            expression = f"$( {message.expression} ) " if message.expression else ""
+            return f"{filename} >> {path}{expression}{message.content}"
+
         def emit_warnings(_, warnings):
             for warning in warnings:
-                emit_warning(ProtocolValidator.format_message(filename, warning))
+                emit_warning(format_message(warning))
 
         def emit_warnings_and_errors_and_exit(errors, warnings):
             emit_warnings(None, warnings)
             for error in errors:
-                emit_error(ProtocolValidator.format_message(filename, error))
+                emit_error(format_message(error))
             raise CriticalError("Exiting")
 
         compiler.protocol_lang.to.pvm(protocol).match(
@@ -195,3 +238,23 @@ class TetraflowValidator(SourceValidator):
 
     def validate(self):
         pass
+
+
+class SchemaValidator(SourceValidator):
+    """
+    Validates a schema artifact's source files
+    """
+
+    def validate(self):
+        package_content = set(os.listdir(self._path))
+        if (
+            "schema.yml" not in package_content
+            and "schema.yaml" not in package_content
+            and "schema.json" not in package_content
+        ):
+            raise CriticalError("Schema package must contain 'schema.[yml|yaml|json]'.")
+        if (
+            "expected.csv" not in package_content
+            and "expected.ndjson" not in package_content
+        ):
+            raise CriticalError("Schema package must contain 'expected.[csv|ndjson]'.")
