@@ -25,7 +25,7 @@ class ArtifactConfig(InteractiveConfig):
     Artifact Configuration Abstract Class
     """
 
-    def __init__(self, args, *, interactive: bool, has_function=False):
+    def __init__(self, args, *, interactive: bool):
         super().__init__(args, interactive=interactive)
         self._cli_config = CliConfig(args)
         self._interactive = interactive
@@ -33,7 +33,6 @@ class ArtifactConfig(InteractiveConfig):
         self.namespace = None
         self.slug = None
         self.version = None
-        self.has_function = has_function
 
     def _parse(self, values: dict) -> dict:
         return {
@@ -45,31 +44,25 @@ class ArtifactConfig(InteractiveConfig):
                 if (values.get("version") or None) is not None
                 else None
             ),
-            "function": values.get("function") or None,
         }
 
     def print(self):
-        print(self.to_string(formatter=_colour_string, add_function=self.has_function))
+        print(self.to_string(colour=True))
 
-    def to_string(self, *, formatter=_ensure_string, add_function: bool = False):
+    def to_string(self, *, colour=False):
         return self.format(
-            {
-                "type": self.get("type"),
-                "namespace": self.get("namespace"),
-                "slug": self.get("slug"),
-                "version": self.get("version"),
-                "function": self.get("function"),
-            },
-            add_function=add_function,
-            formatter=formatter,
+            {key: self.get(key) for key in self._get_keys()}, colour=colour
         )
 
-    def format(self, values: dict, add_function: bool, formatter=_colour_string):
-        values = self._parse(values)
-        artifact_type = formatter(values.get("type"))
-        namespace = formatter(values.get("namespace"))
-        slug = formatter(values.get("slug"))
-        version = formatter(values.get("version"))
-        function_name = formatter(values.get("function"))
-        function_suffix = f"@{function_name}" if add_function else ""
-        return f"{artifact_type}: {namespace}/{slug}:{version}{function_suffix}"
+    def format(self, values: dict, colour=True):
+        artifact_type = self._format_string(values.get("type"), colour=colour)
+        namespace = self._format_string(values.get("namespace"), colour=colour)
+        slug = self._format_string(values.get("slug"), colour=colour)
+        version = self._format_string(values.get("version"), colour=colour)
+        return f"{artifact_type}: {namespace}/{slug}:{version}"
+
+    @staticmethod
+    def _format_string(string: Optional[str], colour: bool):
+        if colour:
+            return _colour_string(string)
+        return _ensure_string(string)
