@@ -82,6 +82,12 @@ def parse_valid_values(values: dict) -> dict:
     }
 
 
+def open_config():
+    path = config_path()
+    os.makedirs(os.path.dirname(path), exist_ok=True)
+    return open(path, "w+", encoding="utf-8")
+
+
 def write_config_file(profile: Optional[str], values: dict) -> bool:
     config = load_home_config_file()
     values = parse_valid_values(values)
@@ -95,14 +101,13 @@ def write_config_file(profile: Optional[str], values: dict) -> bool:
             set_value_in_config(profiles, profile, profile_config)
             set_value_in_config(config, "profiles", profiles)
     config_format = config.get("format", "json")
-    if config_format == "yaml":
-        with open(config_path(), "w") as file:
+    with open_config() as file:
+        if config_format == "yaml":
             yaml.dump(config, file)
-    elif config_format == "json":
-        with open(config_path(), "w") as file:
+        elif config_format == "json":
             json.dump(config, file)
-    else:
-        raise ValueError(f"Unrecognized format: {config_format}")
+        else:
+            raise ValueError(f"Unrecognized format: {config_format}")
     return bool(values)
 
 
