@@ -1,7 +1,8 @@
 from typing import List
 
 from ts_cli.config.provider import Provider
-from ts_cli.util.emit import emit_critical, emit_info, emit_success
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_info, emit_success
 
 
 class Config:
@@ -39,7 +40,9 @@ class Config:
         for key in keys:
             valid &= config.get_pretty(key) is not None
         if not valid:
-            emit_critical(f"Exiting due to incomplete {config_type} configuration")
+            raise CriticalError(
+                f"Exiting due to incomplete {config_type} configuration"
+            )
 
     def validate(self, requirements: List[str]):
         Config._validate_config_keys(self, requirements, self._type)
