@@ -23,19 +23,7 @@ def make_emitter(colorizer: Callable[[str], str], prefix: str, file):
     return applicator
 
 
-_emit_critical = make_emitter(magenta, "", sys.stderr)
-
-
-def emit_critical(message: str):
-    """
-    Emits a critical message to the console, and then exits the process
-    :param message:
-    :return:
-    """
-    _emit_critical(message)
-    sys.exit(1)
-
-
+emit_critical = make_emitter(magenta, "", sys.stderr)
 emit_error = make_emitter(red, "", sys.stderr)
 emit_warning = make_emitter(yellow, "warning: ", sys.stdout)
 emit_info = make_emitter(blue, "", sys.stdout)
